# PyDSLib

PyDSLib is a data structures library, written in Python for Python. It aims to provide an efficient implementation and a 
convenient interface for each data structure, as well as a selection of useful methods and algorithms to manipulate them.

PyDSLib is very much still in development - see the TODO section. We welcome open-source contributions to help improve
this library.

Data structures currently supported include:

- Queue
- Deque
- Stack
- Linked List
- Binary Heap
- Priority Queue
- Binary Search Tree
- AVL Tree
- Graph

# Installation